@@ -3,12 +3,40 @@ import numpy as np
 import os
 
 class FlowPic(NFPlugin):
-    '''
-    File name structure:
+    '''FlowPic | An NxN histogram of packet sizes and relative times, represented as an image.
+    
+    Output Features:
+        Since the FlowPics can get very big and hence consume a lot of memory,
+        instead of outputting the features as a column in a CSV file the images are
+        exported to npz files with the following naming scheme:
         flowpic-[flow_start_time_ms]-[src_ip]-[src_port]-[dst_ip]-[dst_port]-[protocol]-[direction].npz
+        
+        Each FlowPic is captured on a specific time frame/window/subflow, hence, a flow can be partitioned
+        into multiple time frames. In such cases, multiple .npz files can be created.
+        
+        To load the .npz files into memory you can use the following:
+        ```
+        flowpic_sample = np.load(filepath)['flowpic']
+        ```
+    
+    Paper:
+        "FlowPic: Encrypted Internet Traffic Classification is as Easy as Image Recognition".
+
+        By:
+            - Tal Shapira.
+            - Yuval Shavitt.
     
     '''
     def __init__(self, save_path, time_per_subflow=30, min_time_per_subflow=None, min_packets_per_subflow=10, image_dims=(1500, 1500), MTU=1500):
+        '''
+        Args:
+            `save_path` (str): The directory to save the .npz files.
+            `time_per_subflow` (int): Duration for each subflow or time frame/window (in seconds). Default: 30s.
+            `min_time_per_subflow` (int): Minimum duration for a time frame to process (in seconds). Default: 5/6 * `time_per_subflow`
+            `min_packets_per_subflow` (int): Minimum packets for a time frame to process. Default: 10.
+            `image_dims` (int, int): FlowPic output image dimensions. Default: (1500,1500).
+            `MTU` (int): The max packet size to process, packets with size larger than `MTU` will be ignored. Default: 1500.
+        '''
         self.save_path = save_path
         self.time_per_subflow = time_per_subflow
         self.min_time_per_subflow = int(np.ceil(time_per_subflow - time_per_subflow*0.1666667)) if min_time_per_subflow == None else min_time_per_subflow
@@ -17,12 +45,14 @@ class FlowPic(NFPlugin):
         self.mtu = MTU
 
     def on_init(self, packet, flow):
+        ''' '''
         flow.udps.src2dst_flowpic_data = _FlowPicInnerPlugin(flow.src2dst_first_seen_ms, self.mtu)
         flow.udps.dst2src_flowpic_data = None
         
         self.on_update(packet, flow)
 
     def on_update(self, packet, flow):
+        ''' '''
         if packet.ip_size == 0 or packet.ip_size > self.image_dims[0]:
             # discard
             return
@@ -49,6 +79,7 @@ class FlowPic(NFPlugin):
             flow.udps.dst2src_flowpic_data.on_update(packet)
         
     def on_expire(self, flow):
+        ''' '''
         ## SRC -> DST
         if flow.src2dst_packets > 0 \
             and flow.udps.src2dst_flowpic_data.count > self.min_packets_per_subflow \
@@ -69,7 +100,7 @@ class FlowPic(NFPlugin):
         # cleanup
         del flow.udps.src2dst_flowpic_data
         del flow.udps.dst2src_flowpic_data
- 
+
     def save_histogram(self, hist, subflow_start_time, direction, flow):
         np.savez_compressed(
             os.path.join(
