@@ -3,6 +3,10 @@ from ._distiller import DistillerPreprocessing
 from ._maldist import MalDistPreprocessing
 # wrappers
 from ._wrappers import OneHotEncoderEIMTC
+# labellings
+from ._labelling import (
+    FilenameBasedLabelling, DirectoryBasedLabelling
+)
 # general purpose 
 from sklearn.preprocessing import (
     add_dummy_feature, binarize, Binarizer, FunctionTransformer, KBinsDiscretizer, 
@@ -17,6 +21,9 @@ __all__ = [
     'MalDistPreprocessing'
 ] + [ # wrappers
     'OneHotEncoderEIMTC'
+] + [ # labellings
+    'FilenameBasedLabelling', 
+    'DirectoryBasedLabelling'
 ] + [ # general purpose
     'add_dummy_feature',
     'binarize, Binarizer',
