@@ -12,7 +12,7 @@ class OneHotEncoderEIMTC:
     
     @property
     def categories_(self):
-        return self._inner_ohc.categories_
+        return self._inner_ohc.categories_[0]
     
     @property
     def drop_idx_(self):
@@ -39,7 +39,7 @@ class OneHotEncoderEIMTC:
         return self._inner_ohc.transform(X)
     
     def inverse_transform(self, X):
-        return self._inner_ohc.inverse_transform(X)
+        return self._inner_ohc.inverse_transform(X).reshape(-1)
     
     def get_feature_names_out(self, input_features=None):
         if input_features is not None:
